@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -38,6 +38,23 @@ struct deftransaction_data
 {
 	GtkWidget	*window;
 
+
+	GtkWidget	*PO_date;
+	GtkWidget	*PO_pay;
+	GtkWidget	*ST_memo;
+	GtkWidget	*ST_amount, *BT_split;
+	GtkWidget	*CM_cheque;
+
+	GtkWidget	*NU_mode;
+	GtkWidget	*ST_info;
+	GtkWidget	*PO_cat;
+	GtkWidget	*LB_accfrom, *PO_acc;
+	GtkWidget	*LB_accto, *PO_accto;
+	GtkWidget	*ST_tags, *CY_tags;
+	GtkWidget   *RA_status;
+
+	GtkWidget   *IB_warnsign;
+
 	/* popover */
 	GtkWidget   *MB_template;
 	GtkTreeModel *model;
@@ -47,22 +64,6 @@ struct deftransaction_data
 	GtkWidget   *CM_showallacc;
 	GtkWidget   *ST_search;
 
-	GtkWidget	*PO_date;
-	GtkWidget	*PO_pay;
-	GtkWidget	*ST_word;
-	GtkWidget	*ST_amount, *BT_split;
-	GtkWidget	*CM_cheque;
-
-	GtkWidget	*NU_mode;
-	GtkWidget	*ST_info;
-	GtkWidget	*PO_grp;
-	GtkWidget	*PO_acc;
-	GtkWidget	*LB_accto, *PO_accto;
-	GtkWidget	*ST_tags;
-	GtkWidget   *RA_status;
-
-	GtkWidget   *IB_warnsign;
-	
 	gint		action;
 	gint		accnum;
 	gint		type;
@@ -70,9 +71,9 @@ struct deftransaction_data
 	gboolean	showtemplate;
 
 	Transaction *ope;
-
 };
 
+
 enum
 {
 	LST_DSPTPL_DATAS,
